@@ -1,5 +1,5 @@
-import _pgmagick
-__version__ = '0.4.2'
+from pgmagick import _pgmagick
+__version__ = '0.5.1'
 
 
 def __init():
