@@ -516,12 +516,12 @@ void __Image()
         .def("xResolution", &Magick::Image::xResolution)
         .def("yResolution", &Magick::Image::yResolution)
 #if 0
-        .def("getConstPixels", (Magick::PixelPacket* (Magick::Image::*)(int, int, int, int) const)&Magick::Image::getConstPixels, return_value_policy<return_opaque_pointer>())
+        .def("getConstPixels",)
         .def("getIndexes",)
         .def("getConstIndexes",)
+        .def("getPixels",)
         .def("setPixels",)
 #endif
-        .def("getPixels", (Magick::PixelPacket* (Magick::Image::*)(int, int, unsigned int, unsigned int) const)&Magick::Image::getPixels, return_value_policy<return_opaque_pointer>())
         .def("syncPixels", &Magick::Image::syncPixels)
         .def("readPixels", &Magick::Image::readPixels)
         .def("writePixels", &Magick::Image::writePixels)
@@ -538,6 +538,4 @@ void __Image()
         .def( self >= self )
         .def( self <= self )
     ;
-
-    //class_< Magick::Image::getConstPixels >("
 }
